@@ -11,7 +11,6 @@
 
 #include <KLocalizedString>
 
-#include <QRegExp>
 #include <QMap>
 #include <QList>
 
@@ -725,7 +724,7 @@ int Lexer::toInt(const Token& token)
     if (token.type() == Token_number_literal) {
         // hex literal ?
         if (s[0] == '0' && (s[1] == 'x' || s[1] == 'X'))
-            return s.mid(2).toInt(0, 16);
+            return s.mid(2).toInt(nullptr, 16);
         QString n;
         int i = 0;
         while (i < int(s.length()) && s[i].isDigit())
@@ -985,7 +984,7 @@ void Lexer::nextToken(Token& tk, bool stopOnNewline)
 #if defined(KDEVELOP_BGPARSER)
                     qthread_yield();
 #endif
-                    insertCurrent(QString(" ") + (*pos).second + QString(" "));
+                    insertCurrent(QStringLiteral(" ") + (*pos).second + QStringLiteral(" "));
                 }
             } else if ( /*qt_rx.exactMatch(ide) ||*/
                 ide.str().endsWith(QLatin1String("EXPORT")) ||
@@ -1356,7 +1355,7 @@ void Lexer::processInclude()
         QChar ch = currentChar();
         if (ch == '"' || ch == '<') {
             nextChar();
-            QChar ch2 = ch == QChar('"') ? QChar('"') : QChar('>');
+            QChar ch2 = ch == QLatin1Char('"') ? QLatin1Char('"') : QLatin1Char('>');
 
             int startWord = currentPosition();
             if (startWord < 0)
