@@ -1,12 +1,7 @@
-/***************************************************************************
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *  copyright (C) 2006-2020                                                *
- *  Umbrello UML Modeller Authors <umbrello-devel@kde.org>                 *
- ***************************************************************************/
+/*
+    SPDX-License-Identifier: GPL-2.0-or-later
+    SPDX-FileCopyrightText: 2006-2020 Umbrello UML Modeller Authors <umbrello-devel@kde.org>
+*/
 
 #ifndef JAVAIMPORT_H
 #define JAVAIMPORT_H
@@ -24,7 +19,7 @@ class UMLObject;
 class JavaImport : public NativeImportBase
 {
 public:
-    explicit JavaImport(CodeImpThread* thread = 0);
+    explicit JavaImport(CodeImpThread *thread = nullptr);
     virtual ~JavaImport();
 
 protected:
