@@ -34,13 +34,13 @@ int UMLSceneFinder::collect(Category category, const QString &text)
         return 0;
 
     UMLScene *scene = view->umlScene();
-    foreach(UMLWidget* w, scene->widgetList()) {
+    for(UMLWidget* w: scene->widgetList()) {
         if (!includeObject(category, w->umlObject()))
             continue;
         if (w->name().contains(text, Qt::CaseInsensitive))
             m_items.append(w->id());
     }
-    foreach(MessageWidget* w, scene->messageList()) {
+    for(MessageWidget* w: scene->messageList()) {
         if (w->umlObject() && !includeObject(category, w->umlObject()))
             continue;
         if (w->name().contains(text, Qt::CaseInsensitive))
@@ -53,7 +53,7 @@ int UMLSceneFinder::collect(Category category, const QString &text)
 
 UMLFinder::Result UMLSceneFinder::displayNext()
 {
-    if (m_items.size() == 0 || UMLApp::app()->document()->findView(m_id) == 0)
+    if (m_items.size() == 0 || UMLApp::app()->document()->findView(m_id) == nullptr)
         return Empty;
     if (m_index >= m_items.size()-1) {
         m_index = -1;
@@ -64,7 +64,7 @@ UMLFinder::Result UMLSceneFinder::displayNext()
 
 UMLFinder::Result UMLSceneFinder::displayPrevious()
 {
-    if (m_items.size() == 0 || UMLApp::app()->document()->findView(m_id) == 0)
+    if (m_items.size() == 0 || UMLApp::app()->document()->findView(m_id) == nullptr)
         return Empty;
     if (m_index < 1) {
         m_index = m_items.size();
